@@ -3,6 +3,6 @@ package # hide from PAUSE
     
 use base qw/DBIx::Class::Schema/;
 
-__PACKAGE__->load_classes(qw/Test1A Test1B Test2A Test2B Test2C/);
+__PACKAGE__->load_classes(qw/Test1A Test1B Test2A Test2B Test2C Test2D Test3A Test4A/);
 
 1;
\ No newline at end of file
