@@ -17,6 +17,7 @@ CREATE TABLE test1_b (
 DROP TABLE IF EXISTS test2_a;
 DROP TABLE IF EXISTS test2_b;
 DROP TABLE IF EXISTS test2_c;
+DROP TABLE IF EXISTS test2_d;
 
 CREATE TABLE test2_a (
     id INTEGER PRIMARY KEY AUTOINCREMENT,
@@ -35,4 +36,26 @@ CREATE TABLE test2_c (
     name TEXT NOT NULL
 );
 
+CREATE TABLE test2_d (
+    id INTEGER PRIMARY KEY AUTOINCREMENT,
+    name TEXT NOT NULL,
+    c integer
+);
+
+DROP TABLE IF EXISTS test3_a;
+
+CREATE TABLE test3_a (
+    id INTEGER PRIMARY KEY AUTOINCREMENT,
+    name TEXT NOT NULL,
+    a integer
+);
+
+DROP TABLE IF EXISTS test4_a;
+
+CREATE TABLE test4_a (
+    id INTEGER PRIMARY KEY AUTOINCREMENT,
+    name TEXT NOT NULL,
+    a integer
+);
+
 COMMIT;
